.. _optimizers_guide:

================
optimizers guide
================

This guide is currently a work in progress and only contains bullet points for now.

- The typical arguments to an optimizer. They are usually simple and don't require other objects.
- 